from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.country_dto import CountryDto
from pianosdk.publisher.models.region_dto import RegionDto


class UserAddressApiDto(BaseModel):
    user_address_id: Optional[str] = None
    country: Optional['CountryDto'] = None
    region: Optional['RegionDto'] = None
    city: Optional[str] = None
    postal_code: Optional[str] = None
    company_name: Optional[str] = None
    first_name: Optional[str] = None
    last_name: Optional[str] = None
    address1: Optional[str] = None
    address2: Optional[str] = None
    phone: Optional[str] = None


UserAddressApiDto.model_rebuild()
